From: Andrew Morton <akpm@linux-foundation.org>
To: mm-commits@vger.kernel.org, sj@kernel.org, akpm@linux-foundation.org
Subject: [merged mm-stable] mm-damon-vaddr-generalize-damon_va_apply_three_regions.patch removed from -mm tree
Date: Mon, 09 May 2022 21:15:48 -0700 [thread overview]
Message-ID: <20220510041548.EBA4AC385C2@smtp.kernel.org> (raw)
The quilt patch titled
Subject: mm/damon/vaddr: generalize damon_va_apply_three_regions()
has been removed from the -mm tree. Its filename was
mm-damon-vaddr-generalize-damon_va_apply_three_regions.patch
This patch was dropped because it was merged into mm-stable
------------------------------------------------------
From: SeongJae Park <sj@kernel.org>
Subject: mm/damon/vaddr: generalize damon_va_apply_three_regions()
'damon_va_apply_three_regions()' is for adjusting address ranges to fit in
three discontiguous ranges. The function can be generalized for arbitrary
number of discontiguous ranges and reused for future usage, such as
arbitrary online regions update. For such future usage, this commit
introduces a generalized version of the function called
'damon_set_regions()'.
Link: https://lkml.kernel.org/r/20220429160606.127307-4-sj@kernel.org
Signed-off-by: SeongJae Park <sj@kernel.org>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
---
mm/damon/vaddr.c | 66 ++++++++++++++++++++++++++++-----------------
1 file changed, 42 insertions(+), 24 deletions(-)
--- a/mm/damon/vaddr.c~mm-damon-vaddr-generalize-damon_va_apply_three_regions
+++ a/mm/damon/vaddr.c
@@ -297,59 +297,77 @@ static bool damon_intersect(struct damon
}
/*
- * Update damon regions for the three big regions of the given target
+ * damon_set_regions() - Set regions of a target for given address ranges.
+ * @t: the given target.
+ * @ranges: array of new monitoring target ranges.
+ * @nr_ranges: length of @ranges.
*
- * t the given target
- * bregions the three big regions of the target
+ * This function adds new regions to, or modify existing regions of a
+ * monitoring target to fit in specific ranges.
+ *
+ * Return: 0 if success, or negative error code otherwise.
*/
-static void damon_va_apply_three_regions(struct damon_target *t,
- struct damon_addr_range bregions[3])
+static int damon_set_regions(struct damon_target *t,
+ struct damon_addr_range *ranges, unsigned int nr_ranges)
{
struct damon_region *r, *next;
unsigned int i;
/* Remove regions which are not in the three big regions now */
damon_for_each_region_safe(r, next, t) {
- for (i = 0; i < 3; i++) {
- if (damon_intersect(r, &bregions[i]))
+ for (i = 0; i < nr_ranges; i++) {
+ if (damon_intersect(r, &ranges[i]))
break;
}
- if (i == 3)
+ if (i == nr_ranges)
damon_destroy_region(r, t);
}
- /* Adjust intersecting regions to fit with the three big regions */
- for (i = 0; i < 3; i++) {
- struct damon_region *first = NULL, *last;
- struct damon_region *newr;
- struct damon_addr_range *br;
+ /* Add new regions or resize existing regions to fit in the ranges */
+ for (i = 0; i < nr_ranges; i++) {
+ struct damon_region *first = NULL, *last, *newr;
+ struct damon_addr_range *range;
- br = &bregions[i];
- /* Get the first and last regions which intersects with br */
+ range = &ranges[i];
+ /* Get the first/last regions intersecting with the range */
damon_for_each_region(r, t) {
- if (damon_intersect(r, br)) {
+ if (damon_intersect(r, range)) {
if (!first)
first = r;
last = r;
}
- if (r->ar.start >= br->end)
+ if (r->ar.start >= range->end)
break;
}
if (!first) {
- /* no damon_region intersects with this big region */
+ /* no region intersects with this range */
newr = damon_new_region(
- ALIGN_DOWN(br->start,
+ ALIGN_DOWN(range->start,
DAMON_MIN_REGION),
- ALIGN(br->end, DAMON_MIN_REGION));
+ ALIGN(range->end, DAMON_MIN_REGION));
if (!newr)
- continue;
+ return -ENOMEM;
damon_insert_region(newr, damon_prev_region(r), r, t);
} else {
- first->ar.start = ALIGN_DOWN(br->start,
+ /* resize intersecting regions to fit in this range */
+ first->ar.start = ALIGN_DOWN(range->start,
DAMON_MIN_REGION);
- last->ar.end = ALIGN(br->end, DAMON_MIN_REGION);
+ last->ar.end = ALIGN(range->end, DAMON_MIN_REGION);
}
}
+ return 0;
+}
+
+/*
+ * Update damon regions for the three big regions of the given target
+ *
+ * t the given target
+ * bregions the three big regions of the target
+ */
+static void damon_va_apply_three_regions(struct damon_target *t,
+ struct damon_addr_range bregions[3])
+{
+ damon_set_regions(t, bregions, 3);
}
/*
_
Patches currently in -mm which might be from sj@kernel.org are
reply other threads:[~2022-05-10 4:19 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20220510041548.EBA4AC385C2@smtp.kernel.org \
--to=akpm@linux-foundation.org \
--cc=linux-kernel@vger.kernel.org \
--cc=mm-commits@vger.kernel.org \
--cc=sj@kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -297,59 +297,77 @@ static bool damon_intersect(struct damon
struct damon_region *r, *next;
unsigned int i;
- /* Remove regions which are not in the three big regions now */
+ /* Remove regions which are not in the new ranges */
damon_for_each_region_safe(r, next, t) {
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.